Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorJacques Lucke <jacques@blender.org>2020-06-09 11:27:24 +0300
committerJacques Lucke <jacques@blender.org>2020-06-09 11:27:24 +0300
commit9bb7d6ed68ef1aa0e6acc3e70901cb6b79c682d2 (patch)
tree843993222b8ee5c02451207404ceb113323ede6f /source/blender/blenlib/BLI_index_range.hh
parentd8678e02ecec9375bec1dcf1388c6fc8b4ce3ad2 (diff)
BLI: put C++ data structures in "blender" namespace instead of "BLI"
We plan to use the "blender" namespace in other modules as well.
Diffstat (limited to 'source/blender/blenlib/BLI_index_range.hh')
-rw-r--r--source/blender/blenlib/BLI_index_range.hh14
1 files changed, 7 insertions, 7 deletions
diff --git a/source/blender/blenlib/BLI_index_range.hh b/source/blender/blenlib/BLI_index_range.hh
index 4a64ae16589..8a97facd9c0 100644
--- a/source/blender/blenlib/BLI_index_range.hh
+++ b/source/blender/blenlib/BLI_index_range.hh
@@ -20,7 +20,7 @@
/** \file
* \ingroup bli
*
* A `BLI::IndexRange` wraps an interval of non-negative integers. It can be used to reference
* consecutive elements in an array. Furthermore, it can make for loops more convenient and less
* error prone, especially when using nested loops.
*
@@ -35,10 +35,10 @@
* for (uint j : IndexRange(20)) {
* for (uint k : IndexRange(30)) {
*
* Some containers like BLI::Vector have an index_range() method. This will return the IndexRange
* that contains all indices that can be used to access the container. This is particularly useful
* when you want to iterate over the indices and the elements (much like Python's enumerate(), just
* worse). Again, I think the second example here is better:
*
* for (uint i = 0; i < my_vector_with_a_long_name.size(); i++) {
* do_something(i, my_vector_with_a_long_name[i]);
@@ -64,7 +64,7 @@ namespace tbb {
template<typename Value> class blocked_range;
}
-namespace BLI {
+namespace blender {
template<typename T> class ArrayRef;
@@ -236,6 +236,6 @@ class IndexRange {
}
};
-} // namespace BLI
+} // namespace blender
#endif /* __BLI_INDEX_RANGE_HH__ */
@@ -20,7 +20,7 @@
* \ingroup bli
*
- * A `BLI::IndexRange` wraps an interval of non-negative integers. It can be used to reference
+ * A `blender::IndexRange` wraps an interval of non-negative integers. It can be used to reference
* consecutive elements in an array. Furthermore, it can make for loops more convenient and less
* error prone, especially when using nested loops.
@@ -35,10 +35,10 @@
* for (uint k : IndexRange(30)) {
*
- * Some containers like BLI::Vector have an index_range() method. This will return the IndexRange
- * that contains all indices that can be used to access the container. This is particularly useful
- * when you want to iterate over the indices and the elements (much like Python's enumerate(), just
- * worse). Again, I think the second example here is better:
+ * Some containers like blender::Vector have an index_range() method. This will return the
+ * IndexRange that contains all indices that can be used to access the container. This is
+ * particularly useful when you want to iterate over the indices and the elements (much like
+ * Python's enumerate(), just worse). Again, I think the second example here is better:
*
* for (uint i = 0; i < my_vector_with_a_long_name.size(); i++) {